@@ -30,8 +30,8 @@ jomo1con.MCMCchain<- function(Y, X=NULL, beta.start=NULL, l1cov.start=NULL, l1co
   Yimp=Y
   Yimp2=matrix(0, nrow(Y),ncol(Y))
   imp[(nrow(X)+1):(2*nrow(X)),(ncol(Y)+1):(ncol(Y)+ncol(X))]=X
-  imp[(nrow(X)+1):(2*nrow(X)), (ncol(Y)+ncol(X)+1)]=1
-  imp[(nrow(X)+1):(2*nrow(X)), (ncol(Y)+ncol(X)+2)]=c(1:nrow(Y))
+  imp[(nrow(X)+1):(2*nrow(X)), (ncol(Y)+ncol(X)+1)]=c(1:nrow(Y))
+  imp[(nrow(X)+1):(2*nrow(X)), (ncol(Y)+ncol(X)+2)]=1
   betapost<- array(0, dim=c(nrow(beta.start),ncol(beta.start),nburn))
   omegapost<- array(0, dim=c(nrow(l1cov.start),ncol(l1cov.start),nburn))
   meanobs<-colMeans(Y,na.rm=TRUE)
@@ -61,7 +61,7 @@ jomo1con.MCMCchain<- function(Y, X=NULL, beta.start=NULL, l1cov.start=NULL, l1co
   imp<-data.frame(imp)
   if (is.null(colnamy)) colnamy=paste("Y", 1:ncol(Y), sep = "")
   if (is.null(colnamx)) colnamx=paste("X", 1:ncol(X), sep = "")
-  colnames(imp)<-c(colnamy,colnamx,"Imputation","id")
+  colnames(imp)<-c(colnamy,colnamx,"id","Imputation")
   dimnames(betapost)[1] <- list(colnamx)
   dimnames(betapost)[2] <- list(colnamy)
   dimnames(omegapost)[1] <- list(colnamy)
