@@ -52,8 +52,8 @@ jomo1mix.MCMCchain <-
     Yimp=Yi
     Yimp2=matrix(Yimp, nrow(Yimp),ncol(Yimp))
     imp[(nrow(X)+1):(2*nrow(X)),(ncol(Y)+1):(ncol(Y)+ncol(X))]=X
-    imp[(nrow(X)+1):(2*nrow(X)), (ncol(Y)+ncol(X)+1)]=1
-    imp[(nrow(X)+1):(2*nrow(X)), (ncol(Y)+ncol(X)+2)]=c(1:nrow(Y))
+    imp[(nrow(X)+1):(2*nrow(X)), (ncol(Y)+ncol(X)+1)]=c(1:nrow(Y))
+    imp[(nrow(X)+1):(2*nrow(X)), (ncol(Y)+ncol(X)+2)]=1
     betapost<- array(0, dim=c(nrow(beta.start),ncol(beta.start),nburn))
     omegapost<- array(0, dim=c(nrow(l1cov.start),ncol(l1cov.start),nburn))
     meanobs<-colMeans(Yi,na.rm=TRUE)
@@ -88,7 +88,7 @@ jomo1mix.MCMCchain <-
     if (is.null(colnamycat)) colnamycat=paste("Ycat", 1:ncol(Y.cat), sep = "")
     if (is.null(colnamycon)) colnamycon=paste("Ycon", 1:ncol(Y.con), sep = "")
     if (is.null(colnamx)) colnamx=paste("X", 1:ncol(X), sep = "")
-    colnames(imp)<-c(colnamycon,colnamycat,colnamx,"Imputation","id")
+    colnames(imp)<-c(colnamycon,colnamycat,colnamx,"id","Imputation")
     cnycatcomp<-rep(NA,(sum(Y.numcat)-length(Y.numcat)))
     count=0
     for ( j in 1:ncol(Y.cat)) {
